import requests as req
import json
import sys
from datetime import date

# python3 IsidoreAPIToGarganText search nb_replies language
# ex : python3 IsidoreAPIToGarganText "brain muscle" 100 fra

try :
    search = sys.argv[1]
    replies = sys.argv[2]
    language = sys.argv[3]
except :
    print ("! args error\n")
    sys.exit(0)

if replies > 1000:
    print("The number of replier must be less than 1000")
    sys.exit(0)

url = 'https://api.isidore.science/resource/search?q=' + search + '&output=json&replies=' + replies + '&language=http://lexvo.org/id/iso639-3/' + language
resp = req.get(url)
jsontxt = json.loads(resp.content)
docs = jsontxt["response"]["replies"]["content"]["reply"]


# Output File
output = open("output.csv", "w")
header = "title\tsource\tpublication_year\tpublication_month\tpublication_day\tabstract\tauthors\tweight\n"
output.write(header)

for doc in docs:

    # Title
    title = doc["isidore"]["title"]
    if (type(title) != str):
        if(type(title) == list):
            tmp = ''
            for lang in title:
                if type(lang) != str and lang['@xml:lang'] == language[:2]:
                    tmp = lang['$']
            if tmp == '':
                if type(title[0]) == str:
                    title = title[0]
                else:
                    title = title[0]['$']
            else:
                title = tmp
            
        else:
            title = title['$']

    # Source
    source =doc["isidore"]["source_info"]["sourceName"]["$"]

    # Author
    if doc['isidore']['enrichedCreators'] != []:
        list_author = doc["isidore"]["enrichedCreators"]["creator"]
        authors = []
        if(type(list_author) == list):
            for author in list_author:
                authors.append(author["@origin"])
            authors = ';'.join(authors)
        else:
            authors = list_author["@origin"]
    else:
        authors = ''

    #Abstract
    if 'abstract' in doc['isidore'].keys() and doc["isidore"]["abstract"] != []:
        abstract = doc["isidore"]["abstract"]
    else:
        abstract = ''
    if (type(abstract) != str):
        if type(abstract) == list:
            tmp = ''
            for lang in abstract:
                if type(lang) != str and lang['@xml:lang'] == language[:2]:
                    tmp = lang['$']
            if tmp == '':
                if type(abstract[0]) == str:
                    abstract = abstract[0]
                else:
                    abstract = abstract[0]['$']
            else:
                abstract = tmp
        else :
            abstract = abstract['$']

    # Publication Date
    try:
        pdate = '\t'.join(doc["isidore"]["date"]["normalizedDate"].split('-'))
    except Exception as e:
        pdate = str(date.today().year) + '\t01\t01'

    abstract = abstract.encode(encoding = 'UTF-8', errors = 'ignore').decode("utf-8").replace('\t', '').replace('"', '')
    title = title.encode(encoding = 'UTF-8', errors = 'ignore').decode("utf-8").replace('\t', '').replace('"', '')
    source = source.encode(encoding = 'UTF-8', errors = 'ignore').decode("utf-8").replace('\t', '').replace('"', '').replace('\n', '')

    # Output
    row = str(title) + "\t" + source + "\t" + pdate + "\t" + abstract + "\t" + authors + "\t" + str(1) + "\n"
    output.write(row)
